==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectInstancenode.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstancenode_h
#define objectinstancenode_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instancenode {
  t_math _math;
  p_node _nodefrominstantiator;
  int _nodefrominstantiator_isdefault : 1;
  p_node _nodefrommodule;
  int _nodefrommodule_isdefault : 1;
};
#include <admsObject/objectNode.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instancenode_getuid (p_instancenode myinstancenode);
win32_interface gboolean adms_instancenode_cmp (p_instancenode myinstancenode,p_instancenode refinstancenode);
win32_interface p_instancenode adms_instancenode_new_1 (p_node mynodefrominstantiator,p_node mynodefrommodule);
#define adms_instancenode_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_instancenode_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_instancenode_new_impl (p_adms arguments[]);
win32_interface p_instancenode adms_instancenode_impl (void* member);
#define adms_instancenode(member) ((p_instancenode) (member))
#define adms_instancenode_new adms_instancenode_new_1
#define adms_instancenode_isdefault_nodefrominstantiator(instancenode) (adms_instancenode(instancenode)->_nodefrominstantiator_isdefault)
#define adms_instancenode_valueof_nodefrominstantiator(instancenode) (adms_instancenode(instancenode)->_nodefrominstantiator)
#define adms_instancenode_isdefault_nodefrommodule(instancenode) (adms_instancenode(instancenode)->_nodefrommodule_isdefault)
#define adms_instancenode_valueof_nodefrommodule(instancenode) (adms_instancenode(instancenode)->_nodefrommodule)
#define adms_instancenode_valueof_math(instancenode) ((p_math)instancenode)
#define adms_instancenode_valueof_adms(instancenode) ((p_adms)instancenode)
#define adms_instancenode_valueto_nodefrominstantiator(a,b) ((p_instancenode)a)->_nodefrominstantiator=(b)
win32_interface void adms_instancenode_valueto_nodefrominstantiator_impl (p_instancenode myinstancenode,p_node _nodefrominstantiator);
#define adms_instancenode_valueto_nodefrommodule(a,b) ((p_instancenode)a)->_nodefrommodule=(b)
win32_interface void adms_instancenode_valueto_nodefrommodule_impl (p_instancenode myinstancenode,p_node _nodefrommodule);
#endif /* objectinstancenode_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectInstancenode.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectinstancenode_h
#define objectinstancenode_h
#include <admsObject/admsH.h>
#include <admsObject/objectMath.h>
struct s_instancenode {
  t_math _math;
  p_node _nodefrominstantiator;
  int _nodefrominstantiator_isdefault : 1;
  p_node _nodefrommodule;
  int _nodefrommodule_isdefault : 1;
};
#include <admsObject/objectNode.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_instancenode_uid (p_instancenode myinstancenode);
win32_interface int adms_instancenode_cmp (p_instancenode myinstancenode,p_instancenode refinstancenode);
win32_interface p_instancenode adms_instancenode_new(p_node mynodefrominstantiator,p_node mynodefrommodule);
win32_interface p_adms adms_instancenode_new_impl (p_adms arguments[]);
#define adms_instancenode(member) ((p_instancenode) (member))
#define adms_instancenode_isdefault_nodefrominstantiator(instancenode) (adms_instancenode(instancenode)->_nodefrominstantiator_isdefault)
#define adms_instancenode_valueof_nodefrominstantiator(instancenode) (adms_instancenode(instancenode)->_nodefrominstantiator)
#define adms_instancenode_isdefault_nodefrommodule(instancenode) (adms_instancenode(instancenode)->_nodefrommodule_isdefault)
#define adms_instancenode_valueof_nodefrommodule(instancenode) (adms_instancenode(instancenode)->_nodefrommodule)
#define adms_instancenode_valueof_math(instancenode) ((p_math)instancenode)
#define adms_instancenode_valueof_adms(instancenode) ((p_adms)instancenode)
win32_interface inline void adms_instancenode_valueto_nodefrominstantiator (p_instancenode myinstancenode,p_node _nodefrominstantiator);
win32_interface inline void adms_instancenode_valueto_nodefrommodule (p_instancenode myinstancenode,p_node _nodefrommodule);
win32_interface inline void adms_instancenode_free(p_instancenode myinstancenode);
#endif /* objectinstancenode_h */
